==> warperia_Blood-Shield-Tracker_2025-11-04_16-54-59.zip: BloodShieldTracker/Locale/enUS.lua <==
local L = LibStub("AceLocale-3.0"):NewLocale("BloodShieldTracker", "enUS", true, false)

if not L then return end

L["Abbreviated"] = true
L["Absorbed/Total Shields/Percent:"] = true
L["Alternate Minimum"] = true
L["AlternateMinimum_OptDesc"] = "If this value is non-zero, the bar will change to the optimal color when the estimated Death Strike Heal or Blood Shield is equal to or greater than this value.  It will override the calculated minimum Death Strike Heal or Blood Shield."
L["Appearance"] = true
L["Applied Sound"] = true
L["AppliedSoundDesc"] = "The sound to play when a Blood Shield is applied."
L["Bar Background Color"] = true
L["BarBackgroundColor_LowHealth_OptionDesc"] = "Color to use for the background of the bar when health is low."
L["BarBackgroundColor_OptionDesc"] = "Color to use for the background of the bar."
L["Bar Color"] = true
L["BarColor_OptionDesc"] = "Change the color of the bar."
L["Bar Depleted Color"] = true
L["BarHeight_Desc"] = "Change the height of the bar."
L["BarTextColor_OptionDesc"] = "Changes the color of the text on the bar."
L["BarTexture_OptionDesc"] = "Texture to use for the bar."
L["BarWidth_Desc"] = "Change the width of the bar."
L["Blizzard"] = true
L["Blood Shield"] = true
L["Blood Shield Bar"] = true
L["BloodShieldBarColor_OptionDesc"] = "Change the color of the blood shield bar."
L["BloodShieldBar_Desc"] = "The Blood Shield Bar is displayed any time a Blood Shield is present on the Death Knight.  The bar will calculate the initial, maximum value of the shield and will track the remaining value of the shield based on incoming absorbed attacks.  When the shield is removed from the Death Knight, the bar will be removed."
L["Blood Shield bar height"] = true
L["BloodShieldBarTextColor_OptionDesc"] = "Change the color of the text on the blood shield bar."
L["Blood Shield bar width"] = true
L["Blood Shield Data"] = true
L["BloodShieldDepletedBarColor_OptionDesc"] = "Change the depleted color of the Shield Bar.  This will change what color is shown for the part of the bar not filled."
L["Blood Shield Max Value"] = true
L["BloodShieldTracker_Desc"] = "Blood Shield Tracker is an addon for Blood Death Knight tanks.  It provides a bar to track the Blood Shield and a bar to track the estimated Death Strike heal."
L["Blood Shield Usage"] = true
L["Borders"] = true
L["BST"] = true
L["Change the height of the blood shield bar."] = true
L["Change the height of the estimated healing bar."] = true
L["Change the width of the blood shield bar."] = true
L["Change the width of the estimated healing bar."] = true
L["Colors"] = true
L["Colors for Low Health"] = true
L["Colors for Minimum Heal"] = true
L["Colors for Normal Health"] = true
L["Colors for Optimal Heal"] = true
L["Config Mode"] = true
L["Could not determine talents."] = true
L["Current and Maximum"] = true
L["Current and Percent"] = true
L["Current Value"] = true
L["Data Feed"] = true
L["DataFeed_OptionDesc"] = "Sets the value to be passed as the LDB data feed text."
L["Death Strike"] = true
L["Death Strike Heal"] = true
L["Delimited"] = true
L["Dimensions"] = true
L["ElvUI"] = true
L["ElvUIBorders_OptionDesc"] = "If enabled, borders are disabled for bars and replaced with the ElvUI border."
L["ElvUIEnabled_OptionDesc"] = "If enabled, Blood Shield Tracker will customize its display for ElvUI."
L["ElvUIFontFlags_OptionDesc"] = "If enabled, the font flags will be overriden and ElvUI appropriate flags will be used."
L["ElvUIFont_OptionDesc"] = "If enabled, the font is overriden and the standard ElvUI font is used."
L["ElvUITexture_OptionDesc"] = "If enabled, the bar textures are overriden and the normal ElvUI texture is used."
L["Enable"] = true
L["EnableBarDesc"] = "Enable the bar."
L["Enabled"] = true
L["Enable the Blood Shield Bar."] = true
L["Enable the Estimated Healing Bar."] = true
L["EstHealBarMinBackgroundColor_OptionDesc"] = "Change the background color of the Estimated Heal Bar for minimum Death Strike heals. "
L["EstHealBarMinColor_OptionDesc"] = "Change the color of the Estimated Heal Bar for minimum Death Strike heals."
L["EstHealBarMinTextColor_OptionDesc"] = "Change the color of the text of the Estimated Heal Bar for minimum Death Strike heals."
L["EstHealBarOptColor_OptionDesc"] = "Change the color of Estimated Heal Bar for optimal Death Strike heals (i.e. bigger than the minimum)."
L["EstHealBarOptTextColor_OptionDesc"] = "Change the color of the text of the Estimated Heal Bar for optimal Death Strike heals (i.e. bigger than the minimum)."
L["EstHealBarShowText_OptDesc"] = "Toggle showing the text on the estimated heal bar.  If the text is not shown, only the estimated heal will be shown."
L["EstimateBarBSText"] = "Est. BS"
L["Estimate Bar Value"] = true
L["Estimated Healing Bar"] = true
L["EstimatedHealingBar_Desc"] = "The Estimated Healing Bar provides an estimate of the size of the Death Strike heal if Death Strike is used at that moment.  If the heal will be the minimum (i.e. 10% of maximum health) then the bar is red by default.  If the heal is larger than the minimum, an optimal heal, then the bar turns green by default.  You can use these two colors to know when is the best time to Death Strike.  You can configure the colors of both states below."
L["Estimated Healing bar height"] = true
L["Estimated Healing bar width"] = true
L["Fight Duration:"] = true
L["Fixed"] = true
L["Font"] = true
L["Font Flags"] = true
L["FontMonochrome_OptionDesc"] = "Toggles if the font is rendered without anti-aliasing."
L["FontOutline_OptionDesc"] = "Toggles if a black outline is displayed around the font."
L["Font size"] = true
L["Font size for the bars."] = true
L["FontThickOutline_OptionDesc"] = "Toggles if the font is displayed with a thick black outline."
L["Font to use."] = true
L["Font to use for this panel."] = true
L["Full"] = true
L["General Options"] = true
L["HealBarText"] = "Est. Heal"
L["Health Bar"] = true
L["HealthBar_Desc"] = "The Health Bar shows your current and maximum health."
L["Height"] = true
L["HideOOC_OptionDesc"] = "Hide the Estimated Healing Bar when out of combat."
L["Hide out of combat"] = true
L["HideOutOfCombat_OptionDesc"] = "Hide this bar when out of combat."
L["IllumBar_Desc"] = "The Illuminated Healing Bar shows the total of all Illuminated Healing shields currently on the player.  Illuminated Healing is the shield provided by Holy Paladins."
L["Illuminated Healing Bar"] = true
L["Include Blood Shield"] = true
L["IncludeBS_Desc"] = "Toggle if the Blood Shield value is included."
L["Included Absorbs"] = true
L["Include Divine Aegis"] = true
L["IncludeDivineAegisDesc"] = "Toggles if the total value of all Divine Aegis shields on the player is included on the Power Word:Shield bar."
L["IncludeGeneric_Desc"] = "Toggles if this absorb is included in the bar's value."
L["Last Blood Shield Value"] = true
L["Last Death Strike Heal"] = true
L["Last Fight Data"] = true
L["Latency"] = true
L["LDB"] = true
L["Left"] = true
L["Lock bar"] = true
L["LockBarDesc"] = "Lock the bar from moving."
L["Lock damage bar"] = "Lock bar"
L["Lock estimated healing bar"] = "Lock bar"
L["Lock shield bar"] = true
L["Lock status bar"] = true
L["Lock the damage bar from moving."] = true
L["Lock the estimated healing bar from moving."] = true
L["Lock the shield bar from moving."] = true
L["Lock the status bar from moving."] = true
L["Low Health Bar Background Color"] = true
L["Low Health Bar Color"] = true
L["Low Health Text Color"] = true
L["Low Health Threshold"] = true
L["LowHealthThreshold_OptionDesc"] = "Your health is considered low when the percent is below this threshold."
L["Minimap Button"] = true
L["Minimum Bar Background Color"] = true
L["Minimum Bar Color"] = true
L["Minimum Text Color"] = true
L["Min - Max / Avg:"] = true
L["Mode"] = true
L["Monochrome"] = true
L["None"] = true
L["Number Format"] = true
L["NumberFormat_OptionDesc"] = "The format to use for numbers.  Raw indicates no formatting.  Delimited will thousand delimit the number.  Abbreviated will shorten numbers and use indicators such as k and m."
L["Number of Minimum Shields:"] = true
L["One"] = true
L["Only Current"] = true
L["Only for Blood DK"] = true
L["OnlyForBlood_OptionDesc"] = "Toggles if the addon is only enabled for Blood DKs or if it is enabled for any DK.  The Estimated Heal Bar will still work for non-Blood DKs if this is set to false."
L["Only Maximum"] = true
L["Only Percent"] = true
L["Optimal Bar Color"] = true
L["Optimal Text Color"] = true
L["Outline"] = true
L["Position"] = true
L["Position_OptionDesc"] = "Position on the bar to display the value."
L["Precision"] = true
L["Precision_OptionDesc"] = "Specifies the number of digits shown to the right of the decimal point."
L["Progress Bar"] = true
L["PW:S Bar"] = "Power Word:Shield Bar"
L["PWSBar_Desc"] = "When enabled, it tracks the value of the current Power Word:Shield on the player."
L["Raw"] = true
L["Removed Sound"] = true
L["RemovedSoundDesc"] = "The sound to play when a Blood Shield is removed."
L["Right"] = true
L["Scale"] = true
L["ScaleDesc"] = "Set the bar scaling."
L["seconds"] = true
L["Shield Frequency:"] = true
L["ShieldProgress_OptionDesc"] = "Sets what the progress bar of the Blood Shield Bar tracks.  It can be set to the time remaining on the blood shield, the current value of the blood shield, or none if the bar should not change."
L["ShieldSoundEnabledDesc"] = "Enable playing sounds for the Blood Shield."
L["Shields Total/Refreshed/Removed:"] = true
L["ShieldTextFormat_OptionDesc"] = "Specifies the format of the text on the shield bar."
L["Shift + Left-Click to reset."] = true
L["Short Label"] = true
L["ShortLabel_OptionDesc"] = "Toggles if the LDB should use the short label (usually BST) or the full addon name."
L["ShowBar"] = "Show background"
L["ShowBarDesc"] = "Show the bar and border, when disabled only the text will appear."
L["ShowBorder"] = "Show Border"
L["ShowBorderDesc"] = "Show the border around the bar."
L["Show Text"] = true
L["Show Time"] = true
L["ShowTime_OptionDesc"] = "Toggle if the time remaining is shown on the bar."
L["Skinning"] = true
L["Skinning_Desc"] = "These settings allow you to override the default behavior of Blood Shield Tracker to match the look and feel of Tukui and Elvui.  You must logout and back in or use /reloadui in order for these settings to take effect."
L["SoBStacks_OptionDesc"] = "Toggles if the Scent of Blood stacks are displayed on the bar."
L["Sound"] = true
L["StatusBarTexture"] = "Statusbar Texture"
L["Text Color"] = true
L["Text Format"] = true
L["TextFormat_OptionDesc"] = "Specifies the format of the text on the bar."
L["Texture"] = true
L["Thick Outline"] = true
L["TimePosition_OptionDesc"] = "Position on the bar to display the time remaining."
L["Time Remaining"] = true
L["Toggle config mode"] = true
L["Toggles the display of informational messages"] = true
L["Toggle the minimap button"] = true
L["Total Absorbs Bar"] = true
L["TotalAbsorbsBar_Desc"] = "The Total Absorbs Bar shows the combined absorbs/shields on you.  It includes most of the common absorbs but not necessarily every absorb possible."
L["Total Data"] = true
L["Tukui"] = true
L["TukuiBorders_OptionDesc"] = "If enabled, borders are disabled for bars and replaced with the Tukui border."
L["TukuiEnabled_OptionDesc"] = "If enabled, Blood Shield Tracker will customize its display for Tukui."
L["TukuiFontFlags_OptionDesc"] = "If enabled, the font flags will be overriden and Tukui appropriate flags will be used."
L["TukuiFont_OptionDesc"] = "If enabled, the font is overriden and the standard Tukui font is used."
L["TukuiTexture_OptionDesc"] = "If enabled, the bar textures are overriden and the normal Tukui texture is used."
L["Usage Min - Max / Avg:"] = true
L["Use Aura"] = true
L["UseAura_OptionDesc"] = "Toggles if the Blood Shield bar uses the aura or the combat log data."
L["Verbose"] = true
L["Width"] = true
L["X Offset"] = true
L["XOffset_Desc"] = "X offset from the center of the screen."
L["Y Offset"] = true
L["YOffset_Desc"] = "Y offset from the center of the screen."
L["Zero"] = true

==> warperia_Blood-Shield-Tracker_2025-12-12_15-56-07.zip: BloodShieldTracker/Locale/enUS.lua <==
local L = LibStub("AceLocale-3.0"):NewLocale("BloodShieldTracker", "enUS", true, false)

if not L then return end

L["Abbreviated"] = true
L["Absorbed/Total Shields/Percent:"] = true
L["Absorbs Tracked"] = true
L["AbsorbsTracked_OptionDesc"] = "Determines the absorbs tracked.  |cff00ff00All|r tracks every absorb.  |cff00ff00Selected|r tracks only the selected absorbs.  |cff00ff00All Minus Selected|r tracks all absorbs except the ones selected."
L["Actual"] = true
L["All"] = true
L["All Minus Selected"] = true
L["Alternate Minimum"] = true
L["AlternateMinimum_OptDesc"] = "If this value is non-zero, the bar will change to the optimal color when the estimated Death Strike Heal or Blood Shield is equal to or greater than this value.  It will override the calculated minimum Death Strike Heal or Blood Shield."
L["AMSBar_Desc"] = "This bar tracks your Anti-Magic Shell absorb and time remaining."
L["Anchor"] = true
L["Anchor Point"] = true
L["Anchor_Desc"] = "These settings allow a bar to be aligned to another bar or UI item.  These settings override the x, y coordinates.  The bar will automatically re-position based on the anchor."
L["Anchor_OptDesc"] = "Anchors the bar to the selected UI item."
L["AnchorPoint_OptDesc"] = "The point on the anchor to attach to."
L["Anti-Magic Shell Bar"] = true
L["Appearance"] = true
L["Applied Sound"] = true
L["AppliedSoundDesc"] = "The sound to play when a Blood Shield is applied."
L["Bar Background Color"] = true
L["Bar Color"] = true
L["Bar Depleted Color"] = true
L["Bar Point"] = true
L["BarBackgroundColor_LowHealth_OptionDesc"] = "Color to use for the background of the bar when health is low."
L["BarBackgroundColor_OptionDesc"] = "Color to use for the background of the bar."
L["BarColor_OptionDesc"] = "Change the color of the bar."
L["BarHeight_Desc"] = "Change the height of the bar."
L["BarPoint_OptDesc"] = "The point on this bar that is aligned to the anchor."
L["BarTextColor_OptionDesc"] = "Changes the color of the text on the bar."
L["BarTexture_OptionDesc"] = "Texture to use for the bar."
L["BarWidth_Desc"] = "Change the width of the bar."
L["Blizzard"] = true
L["Blood Charge Bar"] = true
L["Blood Shield"] = true
L["Blood Shield Bar"] = true
L["Blood Shield bar height"] = true
L["Blood Shield bar width"] = true
L["Blood Shield Data"] = true
L["Blood Shield Max Value"] = true
L["Blood Shield Usage"] = true
L["BloodChargeBar_Desc"] = "This bar tracks your Blood Charges gained from the Blood Tap talent."
L["BloodChargeProgress_OptionDesc"] = "Sets what the progress bar of the Blood Charge Bar tracks.  It can be set to the time remaining, the current numbers of charges, or none if the bar should not change."
L["BloodShieldBar_Desc"] = "The Blood Shield Bar is displayed any time a Blood Shield is present on the Death Knight.  The bar will calculate the initial, maximum value of the shield and will track the remaining value of the shield based on incoming absorbed attacks.  When the shield is removed from the Death Knight, the bar will be removed."
L["BloodShieldBarColor_OptionDesc"] = "Change the color of the blood shield bar."
L["BloodShieldBarTextColor_OptionDesc"] = "Change the color of the text on the blood shield bar."
L["BloodShieldDepletedBarColor_OptionDesc"] = "Change the depleted color of the Shield Bar.  This will change what color is shown for the part of the bar not filled."
L["BloodShieldTracker_Desc"] = "Blood Shield Tracker is an addon for Blood Death Knight tanks.  It provides a bar to track the Blood Shield and a bar to track the estimated Death Strike heal."
L["Bone Shield Bar"] = true
L["Bone Wall Bar"] = true
L["BoneShieldBar_Desc"] = "This bar tracks your Bone Shield charges and time left."
L["BoneShieldProgress_OptionDesc"] = "Sets what the progress bar tracks.  It can be set to the time remaining, the current numbers of charges, or none if the bar should not change."
L["BoneWallBar_Desc"] = "This bar tracks Bone Wall--the buff from the Tier 16 Tank 2 piece set bonus."
L["Borders"] = true
L["Bottom"] = true
L["BST"] = true
L["Calculated"] = true
L["Change the height of the blood shield bar."] = true
L["Change the height of the estimated healing bar."] = true
L["Change the width of the blood shield bar."] = true
L["Change the width of the estimated healing bar."] = true
L["Charges"] = true
L["Colors"] = true
L["Colors for Low Health"] = true
L["Colors for Minimum Heal"] = true
L["Colors for Normal Health"] = true
L["Colors for Optimal Heal"] = true
L["Compact Runes"] = true
L["Config Mode"] = true
L["Could not determine talents."] = true
L["Current and Maximum"] = true
L["Current and Percent"] = true
L["Current Value"] = true
L["Custom"] = true
L["Data Feed"] = true
L["DataFeed_OptionDesc"] = "Sets the value to be passed as the LDB data feed text."
L["Death Strike"] = true
L["Death Strike Heal"] = true
L["Delimited"] = true
L["Dimensions"] = true
L["ElvUI"] = true
L["ElvUIBorders_OptionDesc"] = "If enabled, borders are disabled for bars and replaced with the ElvUI border."
L["ElvUIEnabled_OptionDesc"] = "If enabled, Blood Shield Tracker will customize its display for ElvUI."
L["ElvUIFont_OptionDesc"] = "If enabled, the font is overriden and the standard ElvUI font is used."
L["ElvUIFontFlags_OptionDesc"] = "If enabled, the font flags will be overriden and ElvUI appropriate flags will be used."
L["ElvUITexture_OptionDesc"] = "If enabled, the bar textures are overriden and the normal ElvUI texture is used."
L["Enable"] = true
L["Enable the Blood Shield Bar."] = true
L["Enable the Estimated Healing Bar."] = true
L["EnableBarDesc"] = "Enable the bar."
L["Enabled"] = true
L["EstHealBarMinBackgroundColor_OptionDesc"] = "Change the background color of the Estimated Heal Bar for minimum Death Strike heals. "
L["EstHealBarMinColor_OptionDesc"] = "Change the color of the Estimated Heal Bar for minimum Death Strike heals."
L["EstHealBarMinTextColor_OptionDesc"] = "Change the color of the text of the Estimated Heal Bar for minimum Death Strike heals."
L["EstHealBarOptColor_OptionDesc"] = "Change the color of Estimated Heal Bar for optimal Death Strike heals (i.e. bigger than the minimum)."
L["EstHealBarOptTextColor_OptionDesc"] = "Change the color of the text of the Estimated Heal Bar for optimal Death Strike heals (i.e. bigger than the minimum)."
L["EstHealBarShowText_OptDesc"] = "Toggle showing the text on the estimated heal bar.  If the text is not shown, only the estimated heal will be shown."
L["Estimate Bar"] = true
L["Estimate Bar Value"] = true
L["EstimateBarBSText"] = "Est. BS"
L["Estimated Healing Bar"] = true
L["Estimated Healing bar height"] = true
L["Estimated Healing bar width"] = true
L["EstimatedHealingBar_Desc"] = "The Estimated Healing Bar provides an estimate of the size of the Death Strike heal if Death Strike is used at that moment.  If the heal will be the minimum (i.e. 10% of maximum health) then the bar is red by default.  If the heal is larger than the minimum, an optimal heal, then the bar turns green by default.  You can use these two colors to know when is the best time to Death Strike.  You can configure the colors of both states below."
L["Fight Duration:"] = true
L["Fixed"] = true
L["Font"] = true
L["Font Flags"] = true
L["Font size"] = true
L["Font size for the bars."] = true
L["Font to use for this panel."] = true
L["Font to use."] = true
L["FontMonochrome_OptionDesc"] = "Toggles if the font is rendered without anti-aliasing."
L["FontOutline_OptionDesc"] = "Toggles if a black outline is displayed around the font."
L["FontThickOutline_OptionDesc"] = "Toggles if the font is displayed with a thick black outline."
L["Frame"] = true
L["Frame_OptDesc"] = "If Anchor is Custom, the bar is anchored to this frame.  If the frame cannot be found, the bar is positioned with its x, y coordinates. "
L["Full"] = true
L["General Options"] = true
L["HealBarText"] = "Est. Heal"
L["Health Bar"] = true
L["HealthBar_Desc"] = "The Health Bar shows your current and maximum health."
L["Height"] = true
L["Hide out of combat"] = true
L["HideOOC_OptionDesc"] = "Hide the Estimated Healing Bar when out of combat."
L["HideOutOfCombat_OptionDesc"] = "Hide this bar when out of combat."
L["IllumBar_Desc"] = "The Illuminated Healing Bar shows the total of all Illuminated Healing shields currently on the player.  Illuminated Healing is the shield provided by Holy Paladins."
L["Illuminated Healing Bar"] = true
L["Include Blood Shield"] = true
L["Include Divine Aegis"] = true
L["IncludeBS_Desc"] = "Toggle if the Blood Shield value is included."
L["Included Absorbs"] = true
L["IncludeDivineAegisDesc"] = "Toggles if the total value of all Divine Aegis shields on the player is included on the Power Word:Shield bar."
L["IncludeGeneric_Desc"] = "Toggles if this absorb is included in the bar's value."
L["Last Blood Shield Value"] = true
L["Last Death Strike Heal"] = true
L["Last Fight Data"] = true
L["Latency"] = true
L["Layout"] = true
L["LDB"] = true
L["Left"] = true
L["Lock bar"] = true
L["Lock damage bar"] = "Lock bar"
L["Lock estimated healing bar"] = "Lock bar"
L["Lock shield bar"] = true
L["Lock status bar"] = true
L["Lock the damage bar from moving."] = true
L["Lock the estimated healing bar from moving."] = true
L["Lock the shield bar from moving."] = true
L["Lock the status bar from moving."] = true
L["LockBarDesc"] = "Lock the bar from moving."
L["Low Health Bar Background Color"] = true
L["Low Health Bar Color"] = true
L["Low Health Text Color"] = true
L["Low Health Threshold"] = true
L["LowHealthThreshold_OptionDesc"] = "Your health is considered low when the percent is below this threshold."
L["Min - Max / Avg:"] = true
L["Minimap Button"] = true
L["Minimum Bar Background Color"] = true
L["Minimum Bar Color"] = true
L["Minimum Text Color"] = true
L["Mode"] = true
L["Monochrome"] = true
L["None"] = true
L["Number Format"] = true
L["Number of Minimum Shields:"] = true
L["NumberFormat_OptionDesc"] = "The format to use for numbers.  Raw indicates no formatting.  Delimited will thousand delimit the number.  Abbreviated will shorten numbers and use indicators such as k and m."
L["Numeric Timer"] = true
L["One"] = true
L["Only Current"] = true
L["Only for Blood DK"] = true
L["Only Maximum"] = true
L["Only Percent"] = true
L["OnlyForBlood_OptionDesc"] = "Toggles if the addon is only enabled for Blood DKs or if it is enabled for any DK.  The Estimated Heal Bar will still work for non-Blood DKs if this is set to false."
L["Optimal Bar Color"] = true
L["Optimal Text Color"] = true
L["Outline"] = true
L["Percent"] = true
L["Percent_OptDesc"] = "Toggles if the estimate is shown as a value or a percent of maximum health."
L["Position"] = true
L["Position_OptionDesc"] = "Position on the bar to display the value."
L["Precision"] = true
L["Precision_OptionDesc"] = "Specifies the number of digits shown to the right of the decimal point."
L["Progress Bar"] = true
L["ProgressBar_OptionDesc"] = "Sets what the progress bar tracks.  It can be set to the time remaining, the current numbers of charges, or none if the bar should not change."
L["Purgatory Bar"] = true
L["PurgatoryBar_Desc"] = "This bar is displayed when Purgatory is active.  The value shown is the amount that must be healed to avoid instant death."
L["PW:S Bar"] = "Power Word:Shield Bar"
L["PWSBar_Desc"] = "When enabled, it tracks the value of the current Power Word:Shield on the player."
L["Raw"] = true
L["Removed Sound"] = true
L["RemovedSoundDesc"] = "The sound to play when a Blood Shield is removed."
L["Resolve Bar"] = true
L["Resolve Mode"] = true
L["ResolveBar_Desc"] = "A bar that displays the current Resolve for tanks."
L["ResolveMode_OptDesc"] = "Selects which mode is used to determine the Resolve.  Actual uses the value from the tooltip.  Calculated is computed from the weighted damage taken data."
L["Right"] = true
L["Scale"] = true
L["ScaleDesc"] = "Set the bar scaling."
L["seconds"] = true
L["Selected"] = true
L["Shield Bar"] = true
L["Shield Frequency:"] = true
L["ShieldProgress_OptionDesc"] = "Sets what the progress bar of the Blood Shield Bar tracks.  It can be set to the time remaining on the blood shield, the current value of the blood shield, or none if the bar should not change."
L["Shields Total/Refreshed/Removed:"] = true
L["ShieldSoundEnabledDesc"] = "Enable playing sounds for the Blood Shield."
L["ShieldTextFormat_OptionDesc"] = "Specifies the format of the text on the shield bar."
L["Shift + Left-Click to reset."] = true
L["Short Label"] = true
L["ShortLabel_OptionDesc"] = "Toggles if the LDB should use the short label (usually BST) or the full addon name."
L["Show on Cooldown"] = true
L["Show Text"] = true
L["Show Time"] = true
L["Show when Ready"] = true
L["ShowBar"] = "Show background"
L["ShowBarDesc"] = "Show the bar and border, when disabled only the text will appear."
L["ShowBorder"] = "Show Border"
L["ShowBorderDesc"] = "Show the border around the bar."
L["ShowCooldownDesc"] = "Toggles if the bar is shown while Bone Shield is on cooldown.  The time left until it is ready is displayed."
L["ShowReadyDesc"] = "Toggles if the bar is shown when Bone Shield is not active but is not on cooldown."
L["ShowTime_OptionDesc"] = "Toggle if the time remaining is shown on the bar."
L["Skinning"] = true
L["Skinning_Desc"] = "These settings allow you to override the default behavior of Blood Shield Tracker to match the look and feel of Tukui and Elvui.  You must logout and back in or use /reloadui in order for these settings to take effect."
L["SoBStacks_OptionDesc"] = "Toggles if the Scent of Blood stacks are displayed on the bar."
L["Sound"] = true
L["Specializations"] = true
L["StatusBarTexture"] = "Statusbar Texture"
L["Target Swing Timer"] = true
L["Target Swing Timer Bar"] = true
L["TargetSwingTimer_Desc"] = "A swing timer that tracks the main hand swings of your target."
L["Text Color"] = true
L["Text Format"] = true
L["TextFormat_OptionDesc"] = "Specifies the format of the text on the bar."
L["Texture"] = true
L["Thick Outline"] = true
L["Time Remaining"] = true
L["TimePosition_OptionDesc"] = "Position on the bar to display the time remaining."
L["Toggle config mode"] = true
L["Toggle the minimap button"] = true
L["Toggles the display of informational messages"] = true
L["Top"] = true
L["Total Absorbs Bar"] = true
L["Total Data"] = true
L["TotalAbsorbsBar_Desc"] = "The Total Absorbs Bar shows the combined absorbs/shields on you.  It includes most of the common absorbs but not necessarily every absorb possible."
L["Tukui"] = true
L["TukuiBorders_OptionDesc"] = "If enabled, borders are disabled for bars and replaced with the Tukui border."
L["TukuiEnabled_OptionDesc"] = "If enabled, Blood Shield Tracker will customize its display for Tukui."
L["TukuiFont_OptionDesc"] = "If enabled, the font is overriden and the standard Tukui font is used."
L["TukuiFontFlags_OptionDesc"] = "If enabled, the font flags will be overriden and Tukui appropriate flags will be used."
L["TukuiTexture_OptionDesc"] = "If enabled, the bar textures are overriden and the normal Tukui texture is used."
L["Usage Min - Max / Avg:"] = true
L["Use Aura"] = true
L["UseAura_OptionDesc"] = "Toggles if the Blood Shield bar uses the aura or the combat log data."
L["Verbose"] = true
L["Width"] = true
L["X Offset"] = true
L["XOffset_Desc"] = "X offset from the center of the screen."
L["XOffsetAnchor_Desc"] = "The X offset of the bar point from the anchor point."
L["Y Offset"] = true
L["YOffset_Desc"] = "Y offset from the center of the screen."
L["YOffsetAnchor_Desc"] = "The Y offset of the bar point from the anchor point."
L["Zero"] = true
